/*
Copyright © 2021 NAME HERE <EMAIL ADDRESS>

*/
package cmd

import (
	"io/ioutil"
	"log"
	"os"
	"strconv"

	"github.com/spf13/cobra"
)

// editCmd represents the edit command
var editCmd = &cobra.Command{
	Use:   "edit",
	Short: "Edit the title of a diary entry",
	Args:  cobra.ExactArgs(1),
	Long: `
	Opens a file with the title of the entry. Edit this file to edit the title.
	Note that trailing spaces will be trimmed.
	`,
	PreRunE: func(cmd *cobra.Command, args []string) error {
		id, err := strconv.Atoi(args[0])
		if err != nil {
			return err
		}
		_, err = App.Db.GetDiaryEntry(int64(id))
		if err != nil {
			return err
		}
		return nil
	},
	Run: func(cmd *cobra.Command, args []string) {
		id, _ := strconv.Atoi(args[0])
		entry, _ := App.Db.GetDiaryEntry(int64(id))
		temp_file, err := ioutil.TempFile(os.TempDir(), "diary_note_title.*.md")
		if err != nil {
			log.Fatal(err)
		}

		// Preload the data in the file
		_, err = temp_file.Write([]byte(entry.Title))
		if err != nil {
			log.Fatal(err)
		}

		err = OpenEditor(temp_file.Name())
		if err != nil {
			log.Fatal(err)
		}
		new_content, err := ioutil.ReadFile(temp_file.Name())
		if err != nil {
			log.Fatal(err)
		}
		App.Db.EditDiaryEntry(entry.Id, string(new_content))

	},
}

func init() {
	rootCmd.AddCommand(editCmd)
}
